<?php
namespace Pinpoint\Conesso\Cron;

use Magento\Framework\App\Cache\Type\Config;
use Magento\Framework\App\Cache\TypeListInterface;
use Magento\Framework\App\Config\Storage\WriterInterface;
use Magento\Framework\Stdlib\DateTime\DateTime;
use Pinpoint\Conesso\Model\Api\Management\Process\ProcessFactory;
use Pinpoint\Conesso\Model\Config\ContactSettings;

class Customer
{
    /**
     * @var ProcessFactory
     */
    private ProcessFactory $processFactory;

    /**
     * @var ContactSettings
     */
    private ContactSettings $contactSettings;

    /**
     * @var DateTime
     */
    private DateTime $dateTime;

    /**
     * @var TypeListInterface
     */
    private TypeListInterface $cacheTypeList;

    /**
     * @var WriterInterface
     */
    private WriterInterface $configWriter;

    /**
     * @param ProcessFactory $processFactory
     * @param WriterInterface $configWriter
     * @param DateTime $dateTime
     * @param ContactSettings $contactSettings
     * @param TypeListInterface $cacheTypeList
     */
    public function __construct(
        ProcessFactory $processFactory,
        WriterInterface $configWriter,
        DateTime $dateTime,
        ContactSettings $contactSettings,
        TypeListInterface $cacheTypeList
    ) {
        $this->processFactory = $processFactory;
        $this->configWriter = $configWriter;
        $this->contactSettings = $contactSettings;
        $this->dateTime = $dateTime;
        $this->cacheTypeList = $cacheTypeList;
    }

    /**
     * @return void
     */
    public function execute(): void
    {
        if ($this->contactSettings->isModuleEnabled() && $this->contactSettings->isCronEnabled()) {
            if ($this->processFactory->getProcess('customer')->synchronizeData()) {
                $this->configWriter->save(ContactSettings::XML_PATH_LAST_CRON_RUN_TIMESTAMP, $this->dateTime->gmtDate());
                $this->cacheTypeList->cleanType(Config::TYPE_IDENTIFIER);
            }
        }
    }
}
