<?php

namespace Pinpoint\Conesso\Cron;

use Magento\Framework\App\Cache\Type\Config;
use Magento\Framework\App\Cache\TypeListInterface;
use Magento\Framework\Stdlib\DateTime\DateTime;
use Magento\Store\Model\ScopeInterface;
use Pinpoint\Conesso\Model\Api\Management\Process\ProcessFactory;
use Magento\Framework\App\Config\Storage\WriterInterface;
use Pinpoint\Conesso\Model\Config\ProductSettings;

class Products
{
    /**
     * @var ProcessFactory
     */
    private ProcessFactory $processFactory;

    /**
     * @var ProductSettings
     */
    private ProductSettings $productSettings;

    /**
     * @var WriterInterface
     */
    private WriterInterface $configWriter;

    /**
     * @var DateTime
     */
    private DateTime $dateTime;

    /**
     * @var TypeListInterface
     */
    private TypeListInterface $cacheTypeList;

    /**
     * @param ProcessFactory $processFactory
     * @param ProductSettings $productSettings
     * @param WriterInterface $configWriter
     * @param DateTime $dateTime
     * @param TypeListInterface $cacheTypeList
     */
    public function __construct(
        ProcessFactory  $processFactory,
        ProductSettings $productSettings,
        WriterInterface $configWriter,
        DateTime $dateTime,
        TypeListInterface $cacheTypeList
    )
    {
        $this->processFactory = $processFactory;
        $this->productSettings = $productSettings;
        $this->configWriter = $configWriter;
        $this->dateTime = $dateTime;
        $this->cacheTypeList = $cacheTypeList;
    }

    /**
     * @return void
     */
    public function execute(): void
    {
        if ($this->productSettings->isModuleEnabled() && $this->productSettings->isCronEnabled()) {
            if ($this->processFactory->getProcess('products')->synchronizeData()) {
                $this->configWriter->save(ProductSettings::XML_PATH_LAST_CRON_RUN_TIMESTAMP, $this->dateTime->gmtDate());
                $this->cacheTypeList->cleanType(Config::TYPE_IDENTIFIER);
            }
        }
    }
}
