<?php
namespace Pinpoint\Conesso\Model\Api\Repository;

use Magento\Framework\Api\SortOrder;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Exception\CouldNotSaveException;
use Pinpoint\Conesso\Api\Data\ContactSyncInterface;
use Pinpoint\Conesso\Api\Data\ContactSyncInterfaceFactory;
use Pinpoint\Conesso\Api\Repository\ContactsRepositoryInterface;
use Pinpoint\Conesso\Model\ResourceModel\SyncContacts as SyncContactsResourceModel;
use Pinpoint\Conesso\Model\ResourceModel\SyncContacts\CollectionFactory;

class ContactRepository implements ContactsRepositoryInterface
{
    private $syncContactsCollectionFactory;

    private $contactSyncFactory;

    private $syncContactsResourceModel;

    private $connection;

    public function __construct(
        CollectionFactory $syncContactsCollectionFactory,
        SyncContactsResourceModel $syncContactsResourceModel,
        ContactSyncInterfaceFactory $contactSyncFactory,
        ResourceConnection $resourceConnection
    ) {
        $this->contactSyncFactory = $contactSyncFactory;
        $this->syncContactsResourceModel = $syncContactsResourceModel;
        $this->syncContactsCollectionFactory = $syncContactsCollectionFactory;
        $this->connection = $resourceConnection->getConnection();
    }

    public function save(ContactSyncInterface $contactSync)
    {
        try {
            $x = $this->connection->insertOnDuplicate(
                ContactSyncInterface::SCHEMA,
                $contactSync->getData()
            );
            return $x;
        } catch (\Exception $e) {
            throw new CouldNotSaveException(__(
                'Could not save the entity: %1',
                $e->getMessage()
            ));
        }
    }

    public function delete(ContactSyncInterface $contactSync): bool
    {
        $this-> syncContactsResourceModel->delete($contactSync);
        return true;
    }

    public function deleteById(int $id): bool
    {
        try {
            $syncOrders = $this->syncContactsCollectionFactory->create()
                ->addFieldToFilter('id', ['in' => $id]);
            $syncOrders->walk('delete');
            return true;
        } catch (\Exception $e) {
            return false;
        }
    }

    public function getList(\Magento\Framework\Api\SearchCriteriaInterface $searchCriteria)
    {
        $collection = $this->syncContactsCollectionFactory->create();
        foreach ($searchCriteria->getFilterGroups() as $filterGroup) {
            foreach ($filterGroup->getFilters() as $filter) {
                $condition = $filter->getConditionType() ?: 'eq';
                $collection->addFieldToFilter($filter->getField(), [$condition => $filter->getValue()]);
            }
        }
        $sortOrdersData = $searchCriteria->getSortOrders();
        if ($sortOrdersData) {
            foreach ($sortOrdersData as $sortOrder) {
                $collection->addOrder(
                    $sortOrder->getField(),
                    ($sortOrder->getDirection() == SortOrder::SORT_ASC) ? 'ASC' : 'DESC'
                );
            }
        }
        $collection->setCurPage($searchCriteria->getCurrentPage());
        $collection->setPageSize($searchCriteria->getPageSize());
        return $collection->getItems();
    }
}
