<?php
namespace Pinpoint\Conesso\Model\Api\Repository;

use Magento\Framework\Exception\CouldNotSaveException;
use Pinpoint\Conesso\Api\Data\ProductSyncInterface;
use Pinpoint\Conesso\Api\Repository\ProductsSyncRepositoryInterface;
use Pinpoint\Conesso\Model\ResourceModel\SyncProducts\CollectionFactory;
use Pinpoint\Conesso\Api\Data\ProductSyncInterfaceFactory;
use Pinpoint\Conesso\Model\ResourceModel\SyncProducts as SyncProductsResourceModel;
use Magento\Framework\Api\SortOrder;
use Magento\Framework\Api\SearchResultsInterfaceFactory;
use Magento\Framework\App\ResourceConnection;

class ProductsRepository implements ProductsSyncRepositoryInterface
{
    private $productSyncFactory;

    private $productSyncCollectionFactory;

    private $resourceModel;
    private $syncSearchResultsFactory;

    private $connection;

    public function __construct(
        ProductSyncInterfaceFactory $productSyncFactory,
        CollectionFactory $productSyncCollectionFactory,
        SyncProductsResourceModel $resourceModel,
        SearchResultsInterfaceFactory $syncSearchResultsFactory,
        ResourceConnection $resourceConnection
    ) {
        $this->productSyncFactory = $productSyncFactory;
        $this->productSyncCollectionFactory = $productSyncCollectionFactory;
        $this->resourceModel = $resourceModel;
        $this->syncSearchResultsFactory =$syncSearchResultsFactory;
        $this->connection = $resourceConnection->getConnection();

    }
    public function save(ProductSyncInterface $productSync)
    {
        try {
            $x = $this->connection->insertOnDuplicate(
                ProductSyncInterface::SCHEMA,
                $productSync->getData()
            );
            return $x;
        } catch (\Exception $e) {
            throw new CouldNotSaveException(__(
                'Could not save the entity: %1',
                $e->getMessage()
            ));
        }

    }

    public function delete(ProductSyncInterface $productSync): bool
    {
        $this->resourceModel->delete($productSync);
        return true;
    }

    public function deleteById(int $id): bool
    {
        try {
            $syncProducts = $this->productSyncCollectionFactory->create();
            if($id)
                $syncProducts->addFieldToFilter('id', ['in' => $id]);
            $syncProducts->walk('delete');
            return true;
        } catch (\Exception $e) {
            return false;
        }
    }

    public function getList(\Magento\Framework\Api\SearchCriteriaInterface $searchCriteria)
    {
        $collection = $this->productSyncCollectionFactory->create();
        foreach ($searchCriteria->getFilterGroups() as $filterGroup) {
            foreach ($filterGroup->getFilters() as $filter) {
                $condition = $filter->getConditionType() ?: 'eq';
                $collection->addFieldToFilter($filter->getField(), [$condition => $filter->getValue()]);
            }
        }
        $sortOrdersData = $searchCriteria->getSortOrders();
        if ($sortOrdersData) {
            foreach ($sortOrdersData as $sortOrder) {
                $collection->addOrder(
                    $sortOrder->getField(),
                    ($sortOrder->getDirection() == SortOrder::SORT_ASC) ? 'ASC' : 'DESC'
                );
            }
        }
        $collection->setCurPage($searchCriteria->getCurrentPage());
        $collection->setPageSize($searchCriteria->getPageSize());
        return $collection->getItems();
    }
}
